<template>
    <div class="home-container">
        <div style="height: 100%">
          <div class="homeCard">
            <div class="main-card">
            <el-row class="cardTop">
              <el-col :span="12" class="mainCardBtn">
                <el-button type="primary" icon="Plus" size="default" @click="openDialog('add',{})">新增</el-button>
              </el-col>
            </el-row>
            <el-table :data="reportData" style="width: 100%" height="calc(100% - 48px)" :header-cell-style="{ background: '#fafafa' }">
              <el-table-column prop="id" label="id" show-overflow-tooltip></el-table-column>
              <el-table-column prop="name" label="证书名称" show-overflow-tooltip></el-table-column>
              <el-table-column prop="cateName" label="分类名称" show-overflow-tooltip></el-table-column>
              <el-table-column prop="orgName" label="发证机构" show-overflow-tooltip></el-table-column>
              <el-table-column prop="pusTime" label="发证日期" show-overflow-tooltip></el-table-column>
              <el-table-column prop="effectiveTime" label="有效期至" show-overflow-tooltip></el-table-column>
              <el-table-column prop="dueTime" label="到期提醒时间" show-overflow-tooltip></el-table-column>
              <el-table-column prop="notifyUser" label="提醒人" show-overflow-tooltip></el-table-column>
              <el-table-column prop="cateType" label="分类标识" show-overflow-tooltip>
                <template #default="scope">
                  {{getTypeName(scope.row.cateType)}}
                </template>
              </el-table-column>
              <el-table-column prop="files" label="附件" show-overflow-tooltip>
                <template #default="scope">
                  <div v-if="scope.row.files && scope.row.files !== ''">
                    <el-image
                        v-for="(item,index) in scope.row.files.split(',')"
                        style="width: 50px; height: 50px"
                        :src="item"
                        fit="cover"
                        :preview-teleported= true
                    />
                  </div>
                </template>
              </el-table-column>
              <el-table-column label="操作" width="140">
                  <template #default="scope">
                      <el-button size="small" text type="primary" @click="openDialog('update',scope.row)">重新上报</el-button>
                      <el-button style="color: red" size="small" text type="primary" @click="onRowDel(scope.row)">删除</el-button>
                  </template>
              </el-table-column>
            </el-table>
            <div class="pageBtn">
              <el-pagination @size-change="onHandleSizeChange" small="false" @current-change="onHandleCurrentChange" class="page-position" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="listQuery.pageIndex" background v-model:page-size="listQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="total"> </el-pagination>
            </div>
            </div>
          </div>
        </div>
        <add-report ref="reportRef" @refresh="getData"></add-report>
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue'
import { ElMessageBox, ElMessage } from 'element-plus'
import { Plus } from '@element-plus/icons-vue'
import addReport from "./components/addReport.vue"
import {judgeReportApi} from "/@/api/dataUpload/saftyBaseInfo/judgeReport";
interface TableDataState {
  reportData: [],
  listQuery: {
    searchParams: {}
    pageIndex: number
    pageSize: number
  }
  cateTypeList: Array<typeList>
  total: null | number
}

interface typeList{
  value: string
  label: string
}

export default defineComponent({
    name: 'cardInfo',
    components: {addReport },
    setup() {
      const reportRef= ref();
      const state = reactive<TableDataState>({
        reportData: [],
        listQuery: {
          searchParams: {},
          pageIndex: 1,
          pageSize: 10
        },
        total: null,
        cateTypeList: [
          {
            value: 'CATETYPE1',
            label: '营业执照'
          },
          {
            value: 'CATETYPE2',
            label: '安全生产许可证'
          },
          {
            value: 'CATETYPE3',
            label: '危险化学品登记证'
          },
          {
            value: 'CATETYPE4',
            label: '主要负责人考核合格证'
          },
          {
            value: 'CATETYPE5',
            label: '安全管理人员考核合格证'
          },
          {
            value: 'CATETYPE6',
            label: '特种作业人员操作证'
          },
          {
            value: 'CATETYPE0',
            label: '其他'
          }
        ]
      });

      // 页面加载时
      onMounted(() => {
        getData()
      });

      const getData = async ()=>{
        const res = await judgeReportApi().getCardList(state.listQuery)
        if(res.data.code == 200){
          state.reportData = res.data.data
          state.total = res.data.total
        }else{
          ElMessage({
            type: 'warning',
            message: res.data.msg
          })
        }
      }

      const openDialog=(type:string,data:object)=>{
        reportRef.value.open(type,data,state.cateTypeList)
      }

      const getTypeName = (type: string)=>{
        return state.cateTypeList.find(i=>i.value == type)?.label
      }

      // 删除用户
      const onRowDel = (row: Object) => {
          ElMessageBox.confirm(`此操作将永久删除：“${row.name}”，是否继续?`, '提示', {
              confirmButtonText: '确认',
              cancelButtonText: '取消',
              type: 'warning'
          })
              .then(async () => {
                const res = await judgeReportApi().delCard({ids: [row.id]})
                if(res.data.code == 200){
                  ElMessage({
                    type: 'success',
                    message: '删除成功'
                  })
                  await getData()
                }else{
                  ElMessage({
                    type: 'warning',
                    message: res.data.msg
                  })
                }
              })
              .catch(() => {});
      };
      // 分页改变
      const onHandleSizeChange = (val: number) => {
          state.listQuery.pageSize = val;
          getData()
      };
      // 分页改变
      const onHandleCurrentChange = (val: number) => {
          state.listQuery.pageIndex = val;
          getData()
      };

      return {
        reportRef,
        openDialog,
        getTypeName,
        getData,
        onRowDel,
        onHandleSizeChange,
        onHandleCurrentChange,
        ...toRefs(state)
      };
    }
});
</script>
<style lang="scss" scoped>
.home-container {
  height: calc(100vh - 144px);
  box-sizing: border-box;
  overflow: hidden;
  .demo-tabs {
    width: 100%;
    height: 100%;

    &::v-deep(.el-tabs__content) {
      height: calc(100% - 60px);
    }

    .el-tab-pane {
      height: 100%;
    }
  }
  .homeCard {
    width: 100%;
    padding: 20px;
    box-sizing: border-box;
    background: #fff;
    border-radius: 4px;

    .main-card {
      width: 100%;
      height: 100%;
      .cardTop {
        display: flex;
        align-items: center;
        justify-content: space-between;
        margin-bottom: 20px;
        .mainCardBtn {
          margin: 0;
        }
      }
      .pageBtn {
        height: 60px;
        display: flex;
        align-items: center;
        justify-content: right;

        .demo-pagination-block + .demo-pagination-block {
          margin-top: 10px;
        }
        .demo-pagination-block .demonstration {
          margin-bottom: 16px;
        }
      }
    }
    &:last-of-type {
      height: calc(100% - 100px);
    }
  }
  .el-row {
    display: flex;
    align-items: center;
    margin-bottom: 20px;
    &:last-child {
      margin-bottom: 0;
    }
    .grid-content {
      align-items: center;
      min-height: 36px;
    }

    .topInfo {
      display: flex;
      align-items: center;
      font-size: 16px;
      font-weight: bold;

      & > div {
        white-space: nowrap;
        margin-right: 20px;
      }
    }
  }
  .el-card {
    border: 0;
  }
}
</style>
